! $Id: graph_facto_mod.f90 235 2011-06-20 10:33:58Z fhrouet $
! Module for the incomplete Cholesky factorization.
! This is the only file you have to modify.

module graph_facto
  use graph
  implicit none

contains

  subroutine Chol_IC (g, dim, p, md, trace)
  ! Compute the graph of the factors,
  ! using a incomplete (level fill) Cholesky factorization.
  ! Input:
  !  dim: Number of columns 
  !  p  : Maximum fill level allowed
  !  trace: To control level of print (0=no print)
  ! Input/output
  !  g  : On input holds the graph of the original matrix.
  !       Modified in output to hold the
  !       graph of the incomplete factors L
  ! Output
  !  md : Number of diagonal elements modified when 
  !       positive definiteness is lost
    integer, intent(in) :: dim, p, trace
    type(cell), dimension(dim), intent(inout) :: g
    integer, intent(out):: md
    ! ============================
    ! Work to be done
      write (6,*) " ***** TO BE DONE ********* "
    ! ============================
    return

  end subroutine Chol_IC

end module graph_facto

